/*
 * Copyright © 2014 Jon Turney
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice (including the next
 * paragraph) shall be included in all copies or substantial portions of the
 * Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */

#ifndef WINDOWSDRICONST_H
#define WINDOWSDRICONST_H

/* Requests */
#define X_WindowsDRIQueryVersion                 0
#define X_WindowsDRIQueryDirectRenderingCapable  1
#define X_WindowsDRIQueryDrawable                9
#define X_WindowsDRIFBConfigToPixelFormat       10

/* Events */
#define WindowsDRINumberEvents                   0

/* Errors */
#define WindowsDRIClientNotLocal                 0
#define WindowsDRINumberErrors                   (WindowsDRIClientNotLocal + 1)

/* Kinds of Drawables */
#define WindowsDRIDrawableWindow                 0
#define WindowsDRIDrawablePixmap                 1
#define WindowsDRIDrawablePbuffer                2

#endif /* WINDOWSDRICONST_H */
